@@ -22,6 +22,7 @@ from IPython.utils.traitlets import (List, Unicode, CRegExp)
 # ## Custom launchers
 
 timeout_params = ["--timeout=30", "--IPEngineApp.wait_for_url_file=960"]
+controller_params = ["--nodb", "--hwm=1", "--scheme=lru"]
 
 # ## Platform LSF
 class BcbioLSFEngineSetLauncher(launcher.LSFEngineSetLauncher):
@@ -46,8 +47,9 @@ class BcbioLSFControllerLauncher(launcher.LSFControllerLauncher):
     default_template = traitlets.Unicode("""#!/bin/sh
 #BSUB -J bcbio-ipcontroller
 #BSUB -oo bcbio-ipcontroller.bsub.%%J
-%s --ip=* --log-to-file --profile-dir="{profile_dir}" --cluster-id="{cluster_id}" --nodb --hwm=5 --scheme=pure
-    """%(' '.join(map(pipes.quote, launcher.ipcontroller_cmd_argv))))
+%s --ip=* --log-to-file --profile-dir="{profile_dir}" --cluster-id="{cluster_id}" %s
+    """%(' '.join(map(pipes.quote, launcher.ipcontroller_cmd_argv)),
+         ' '.join(controller_params)))
     def start(self):
         return super(BcbioLSFControllerLauncher, self).start()
 
@@ -79,8 +81,9 @@ class BcbioSGEControllerLauncher(launcher.SGEControllerLauncher):
     default_template = traitlets.Unicode(u"""#$ -V
 #$ -S /bin/sh
 #$ -N ipcontroller
-%s --ip=* --log-to-file --profile-dir="{profile_dir}" --cluster-id="{cluster_id}" --nodb --hwm=5 --scheme=pure
-"""%(' '.join(map(pipes.quote, launcher.ipcontroller_cmd_argv))))
+%s --ip=* --log-to-file --profile-dir="{profile_dir}" --cluster-id="{cluster_id}" %s
+"""%(' '.join(map(pipes.quote, launcher.ipcontroller_cmd_argv)),
+     ' '.join(controller_params)))
     def start(self):
         return super(BcbioSGEControllerLauncher, self).start()
 
@@ -122,8 +125,9 @@ class BcbioPBSControllerLauncher(launcher.PBSControllerLauncher):
     default_template = traitlets.Unicode(u"""#PBS -V
 #PBS -S /bin/sh
 #PBS -N ipcontroller
-%s --ip=* --log-to-file --profile-dir="{profile_dir}" --cluster-id="{cluster_id}" --nodb --hwm=5 --scheme=pure
-"""%(' '.join(map(pipes.quote, launcher.ipcontroller_cmd_argv))))
+%s --ip=* --log-to-file --profile-dir="{profile_dir}" --cluster-id="{cluster_id}" %s
+"""%(' '.join(map(pipes.quote, launcher.ipcontroller_cmd_argv)),
+     ' '.join(controller_params)))
 
     def start(self):
         return super(BcbioPBSControllerLauncher, self).start()
@@ -136,27 +140,33 @@ class TORQUELauncher(launcher.BatchSystemLauncher):
         help="The PBS submit command ['qsub']")
     delete_command = List(['qdel'], config=True,
         help="The PBS delete command ['qsub']")
-    job_id_regexp = CRegExp(r'\d+', config=True,
+    job_id_regexp = CRegExp(r'\d+(\[\])?', config=True,
         help="Regular expresion for identifying the job ID [r'\d+']")
 
     batch_file = Unicode(u'')
-    job_array_regexp = CRegExp('#PBS\W+-t\W+[\w\d\-\$]+')
-    job_array_template = Unicode('#PBS -t 1-{n}')
+    #job_array_regexp = CRegExp('#PBS\W+-t\W+[\w\d\-\$]+')
+    #job_array_template = Unicode('#PBS -t 1-{n}')
     queue_regexp = CRegExp('#PBS\W+-q\W+\$?\w+')
     queue_template = Unicode('#PBS -q {queue}')
 
 class BcbioTORQUEEngineSetLauncher(TORQUELauncher, launcher.BatchClusterAppMixin):
     """Launch Engines using PBS"""
+    cores = traitlets.Integer(1, config=True)
     batch_file_name = Unicode(u'torque_engines', config=True,
         help="batch file name for the engine(s) job.")
     default_template= Unicode(u"""#!/bin/sh
 #PBS -V
+#PBS -j oe
 #PBS -N ipengine
+#PBS -t 1-{n}
+#PBS -l nodes=1:ppn={cores}
+#PBS -l walltime=239:00:00
 %s --profile-dir="{profile_dir}" --cluster-id="{cluster_id}"
 """%(' '.join(map(pipes.quote,launcher.ipengine_cmd_argv))))
 
     def start(self, n):
         """Start n engines by profile or profile_dir."""
+        self.context["cores"] = self.cores
         return super(BcbioTORQUEEngineSetLauncher, self).start(n)
 
 class BcbioTORQUEControllerLauncher(TORQUELauncher, launcher.BatchClusterAppMixin):
@@ -167,9 +177,11 @@ class BcbioTORQUEControllerLauncher(TORQUELauncher, launcher.BatchClusterAppMixi
     default_template= Unicode("""#!/bin/sh
 #PBS -V
 #PBS -N ipcontroller
-%s --ip=* --log-to-file --profile-dir="{profile_dir}" --cluster-id="{cluster_id}" --nodb --hwm=5 --scheme=pure
-"""%(' '.join(map(pipes.quote, launcher.ipcontroller_cmd_argv))))
-
+#PBS -j oe
+#PBS -l walltime=239:00:00
+%s --ip=* --log-to-file --profile-dir="{profile_dir}" --cluster-id="{cluster_id}" %s
+"""%(' '.join(map(pipes.quote, launcher.ipcontroller_cmd_argv)),
+     ' '.join(controller_params)))
 
     def start(self):
         """Start the controller by profile or profile_dir."""
@@ -203,9 +215,9 @@ class BcbioPBSPROControllerLauncher(PBSPROLauncher, launcher.BatchClusterAppMixi
     default_template= Unicode("""#!/bin/sh
 #PBS -V
 #PBS -N ipcontroller
-%s --ip=* --log-to-file --profile-dir="{profile_dir}" --cluster-id="{cluster_id}" --nodb --hwm=5 --scheme=pure
-"""%(' '.join(map(pipes.quote, launcher.ipcontroller_cmd_argv))))
-
+%s --ip=* --log-to-file --profile-dir="{profile_dir}" --cluster-id="{cluster_id}" %s
+"""%(' '.join(map(pipes.quote, launcher.ipcontroller_cmd_argv)),
+     ' '.join(controller_params)))
 
     def start(self):
         """Start the controller by profile or profile_dir."""
